@@ -4,20 +4,21 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: Xrm.cc,v 1.6 1997/11/04 19:51:38 mromberg Exp $
+// $Id: Xrm.cc,v 1.12 1999/11/17 06:36:13 bgrayson Exp $
 //
 
 #include <string.h>
 #include <stdlib.h>
-#include <stdio.h>	//  For sprintf().
+#include <stdio.h>	//  For snprintf().
 #include <ctype.h>
 #include <iostream.h>
 #include <unistd.h>  //  for access(), etc.  BCG
+#include "snprintf.h"
 #include "general.h"
 #include "Xrm.h"
 #include "Xrmcommandline.h"
 
-CVSID("$Id: Xrm.cc,v 1.6 1997/11/04 19:51:38 mromberg Exp $");
+CVSID("$Id: Xrm.cc,v 1.12 1999/11/17 06:36:13 bgrayson Exp $");
 CVSID_DOT_H(XRM_H_CVSID);
 CVSID_DOT_H2(XRMCOMMANDLINE_H_CVSID);
 
@@ -57,7 +58,8 @@ Xrm::getDisplayName (int argc, char** argv)
   //  See if '-display foo:0' is on the command line, and return it if it is.
   char** argp;
 
-  for (argp = argv; (*argp != NULL) && (strcmp (*argp, "-display")); argp++)
+  for (argp = argv; (*argp != NULL) &&
+      (strncasecmp (*argp, "-display", 9)); argp++)
     ;  //  Don't do anything.
 
   //  If we found -display and the next word exists...
@@ -71,13 +73,8 @@ Xrm::getDisplayName (int argc, char** argv)
 
 const char *Xrm::getResource(const char *rname) const{
   char frn[1024], fcn[1024];
-  strcpy(frn, instanceName());
-  strcat(frn, ".");
-  strcat(frn, rname);
-  
-  strcpy(fcn, className());
-  strcat(fcn, ".");
-  strcat(fcn, rname);
+  snprintf(frn, 1024, "%s.%s", instanceName(), rname);
+  snprintf(fcn, 1024, "%s.%s", className(), rname);
 
   XrmValue val;
   val.addr = NULL;
@@ -91,11 +88,11 @@ const char *Xrm::getResource(const char *rname) const{
   if (!val.addr)
   {
     //  Let's try with a non-uppercased class name.
-    strcpy (fcn, className());
-    char* p = fcn;
+    char fcn_lower[1024];
+    strncpy(fcn_lower, className(), 1024);
+    char* p = fcn_lower;
     while (p && *p)  *p++ = tolower(*p);
-    strcat (fcn, ".");
-    strcat (fcn, rname);
+    snprintf(fcn, 1024, "%s.%s", fcn_lower, rname);
     XrmGetResource(_db, frn, fcn, &type, &val);
   }
 
@@ -146,8 +143,17 @@ Listed from weakest to strongest:
   char rfilename[2048];
 
   // Get the app-defaults
-  strcpy(rfilename, "/usr/X11R6/lib/X11/app-defaults/");
-  strcat(rfilename, XrmQuarkToString(_class));
+  snprintf(rfilename, 2048, "/usr/X11R6/lib/X11/app-defaults/%s",
+      XrmQuarkToString(_class));
+  if (rfilename != NULL)
+    XrmCombineFileDatabase (rfilename, &_db, 1);
+  //  Try a few more, for SunOS/Solaris folks.
+  snprintf(rfilename, 2048, "/usr/openwin/lib/X11/app-defaults/%s",
+      XrmQuarkToString(_class));
+  if (rfilename != NULL)
+    XrmCombineFileDatabase (rfilename, &_db, 1);
+  snprintf(rfilename, 2048, "/usr/local/X11R6/lib/X11/app-defaults/%s",
+      XrmQuarkToString(_class));
   if (rfilename != NULL)
     XrmCombineFileDatabase (rfilename, &_db, 1);
 
@@ -156,7 +162,7 @@ Listed from weakest to strongest:
   if (xappdir != NULL)
   {
     char xappfile[1024];
-    sprintf (xappfile, "%s/%s", xappdir, className());
+    snprintf (xappfile, 1024, "%s/%s", xappdir, className());
     // this did not work for XAPPLRESDIR
     //if (!access (xappfile, X_OK | R_OK))  
     if (!access (xappfile, R_OK))
@@ -185,8 +191,8 @@ Listed from weakest to strongest:
   //  Now, check for a user resource file, and merge it in if there is one...
   if ( getenv( "HOME" ) != NULL ){
     char userrfilename[1024];
-    strcpy(userrfilename, getenv("HOME"));
-    strcat(userrfilename, "/.Xdefaults");
+    char *home = getenv("HOME");
+    snprintf(userrfilename, 1024, "%s/.Xdefaults", home);
     //  User file overrides system (_db).
     XrmCombineFileDatabase (userrfilename, &_db, 1);
   }
