@@ -1,11 +1,11 @@
 //
-// $Id: Xrmcommandline.h,v 1.15 1998/05/17 21:26:19 bgrayson Exp $
+// $Id: Xrmcommandline.h,v 1.20 1999/11/17 05:53:02 bgrayson Exp $
 //
 
 #ifndef _Xrmcommandline_h
 #define _Xrmcommandline_h
 
-#define XRMCOMMANDLINE_H_CVSID "$Id: Xrmcommandline.h,v 1.15 1998/05/17 21:26:19 bgrayson Exp $"
+#define XRMCOMMANDLINE_H_CVSID "$Id: Xrmcommandline.h,v 1.20 1999/11/17 05:53:02 bgrayson Exp $"
 
 #include <X11/Xresource.h>
 
@@ -24,12 +24,11 @@ static XrmOptionDescRec options[] = {
 //  XOSView-specific resources:
 { "-labels", "*labels", XrmoptionNoArg, "False" },
 { "+labels", "*labels", XrmoptionNoArg, "True" },
+{ "-captions", "*captions", XrmoptionNoArg, "False" },
+{ "+captions", "*captions", XrmoptionNoArg, "True" },
 { "-usedlabels", "*usedlabels", XrmoptionNoArg, "False" },
 { "+usedlabels", "*usedlabels", XrmoptionNoArg, "True" },
-//  This next one is not yet supported.
-#if 0
 { "-samplesPerSec", "*samplesPerSec", XrmoptionSepArg, (caddr_t) NULL },
-#endif
 //  CPU resources
 { "-cpu", "*cpu", XrmoptionNoArg, "False" },
 { "+cpu", "*cpu", XrmoptionNoArg, "True" },
@@ -62,11 +61,12 @@ static XrmOptionDescRec options[] = {
 { "+page", "*page", XrmoptionNoArg, "True" },
 { "-pagespeed", "*pageBandWidth", XrmoptionSepArg, (caddr_t) NULL },
 
-#if defined(XOSVIEW_NETBSD) || defined(XOSVIEW_FREEBSD) || defined(XOSVIEW_OPENBSD)
+#if !defined(__hpux__) && !defined(__hpux)
 //  Disk Meter Options
 { "-disk", "*disk", XrmoptionNoArg, "False" },
 { "+disk", "*disk", XrmoptionNoArg, "True" },
 #endif
+
 // Interrupt meter resources  --  all sorts of aliases.
 { "-int", "*interrupts", XrmoptionNoArg, "False" },
 { "+int", "*interrupts", XrmoptionNoArg, "True" },
@@ -74,6 +74,13 @@ static XrmOptionDescRec options[] = {
 { "+ints", "*interrupts", XrmoptionNoArg, "True" },
 { "-interrupts", "*interrupts", XrmoptionNoArg, "False" },
 { "+interrupts", "*interrupts", XrmoptionNoArg, "True" },
+
+// Intrate meter resources, for platforms that support it.
+{ "-irqrate", "*irqrate", XrmoptionNoArg, "False" },
+{ "+irqrate", "*irqrate", XrmoptionNoArg, "True" },
+{ "-intrate", "*irqrate", XrmoptionNoArg, "False" },
+{ "+intrate", "*irqrate", XrmoptionNoArg, "True" },
+
 //  Special, catch-all option here --
 //    xosview -xrm "*memFreeColor: purple" should work, for example.
 { "-xrm", "*xrm", XrmoptionResArg, (caddr_t) NULL },
