@@ -4,12 +4,12 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: bitmeter.h,v 1.4 1998/03/07 21:20:38 mromberg Exp $
+// $Id: bitmeter.h,v 1.5 1999/01/23 18:34:26 mromberg Exp $
 //
 #ifndef _BITMETER_H_
 #define _BITMETER_H_
 
-#define BITMETER_H_CVSID "$Id: bitmeter.h,v 1.4 1998/03/07 21:20:38 mromberg Exp $"
+#define BITMETER_H_CVSID "$Id: bitmeter.h,v 1.5 1999/01/23 18:34:26 mromberg Exp $"
 
 #include "meter.h"
 
@@ -19,7 +19,7 @@ class BitMeter : public Meter {
 public:
   BitMeter( XOSView *parent,  
 	    const char *title = "", const char *legend ="",
-	    int numBits = 1, int dolegends = 0, int dousedlegends = 0 );
+	    int numBits = 1, int docaptions = 0, int dolegends = 0, int dousedlegends = 0 );
   virtual ~BitMeter( void );
 
   void checkevent( void );
