@@ -4,12 +4,12 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: fieldmeter.h,v 1.8 1998/04/07 13:15:47 bgrayson Exp $
+// $Id: fieldmeter.h,v 1.13 1999/01/31 20:03:32 bgrayson Exp $
 //
 #ifndef _FIELDMETER_H_
 #define _FIELDMETER_H_
 
-#define FIELDMETER_H_CVSID "$Id: fieldmeter.h,v 1.8 1998/04/07 13:15:47 bgrayson Exp $"
+#define FIELDMETER_H_CVSID "$Id: fieldmeter.h,v 1.13 1999/01/31 20:03:32 bgrayson Exp $"
 
 #include "meter.h"
 #include "timer.h"
@@ -18,12 +18,13 @@ class FieldMeter : public Meter {
 public:
   FieldMeter( XOSView *parent, int numfields,
 	      const char *title = "", const char *legend = "", 
-	      int dolegends = 0, int dousedlegends = 0 );
+	      int docaptions = 0, int dolegends = 0, int dousedlegends = 0 );
   virtual ~FieldMeter( void );
   
   virtual void drawfields( int manditory = 0 );
   void setfieldcolor( int field, const char *color );
   void setfieldcolor( int field, unsigned long color);
+  void docaptions( int val ) { docaptions_ = val; }
   void dolegends( int val ) { dolegends_ = val; }
   void dousedlegends( int val ) { dousedlegends_ = val; }
   void reset( void );
@@ -42,11 +43,14 @@ protected:
   enum UsedType { INVALID_0, FLOAT, PERCENT, AUTOSCALE, INVALID_TAIL };
 
   int numfields_;
-  float *fields_, total_, used_, lastused_;
+  float *fields_;
+  float total_, used_, lastused_;
   int *lastvals_, *lastx_;
-  unsigned long *colors_, usedcolor_;
+  unsigned long *colors_;
+  unsigned long usedcolor_;
   UsedType print_;
   int printedZeroTotalMesg_;
+  int numWarnings_;
 
   void SetUsedFormat ( const char * const str );
   void drawlegend( void );
@@ -61,7 +65,8 @@ private:
 protected:
   void IntervalTimerStart() { _timer.start(); }
   void IntervalTimerStop() { _timer.stop(); }
-  long long IntervalTimeInMicrosecs() { return _timer.report(); }
+  LONG_LONG IntervalTimeInMicrosecs() { return _timer.report(); }
+  double IntervalTimeInSecs() { return _timer.report()/1e6; }
 };
 
 #endif
