@@ -12,7 +12,7 @@
 //    should have received.  If not, contact one of the xosview
 //    authors for a copy.
 //
-// $Id: fieldmeterdecay.cc,v 1.10 1998/04/06 03:24:17 bgrayson Exp $
+// $Id: fieldmeterdecay.cc,v 1.12 1999/01/23 18:34:26 mromberg Exp $
 //
 
 // In order to use the FieldMeterDecay class in place of a FieldMeter class in
@@ -27,20 +27,21 @@
 //	 dodecay_ variable according to the, e.g., xosview*cpuDecay resource.
 
 #include <fstream.h>
-#include <stdio.h>
 #include <math.h>		//  For fabs()
 #include "general.h"
 #include "fieldmeter.h"
 #include "fieldmeterdecay.h"
 #include "xosview.h"
 
-CVSID("$Id: fieldmeterdecay.cc,v 1.10 1998/04/06 03:24:17 bgrayson Exp $");
+CVSID("$Id: fieldmeterdecay.cc,v 1.12 1999/01/23 18:34:26 mromberg Exp $");
 CVSID_DOT_H(FIELDMETERDECAY_H_CVSID);
 
 FieldMeterDecay::FieldMeterDecay( XOSView *parent,
                 int numfields, const char *title,
-                const char *legend, int dolegends, int dousedlegends )
-: FieldMeter (parent, numfields, title, legend, dolegends, dousedlegends)
+                const char *legend, int docaptions, int dolegends,
+                int dousedlegends )
+: FieldMeter (parent, numfields, title, legend, docaptions, dolegends,
+              dousedlegends)
 {
   decay_ = new float[numfields];
   lastDecayval_ = new float[numfields];
