@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: cpumeter.cc,v 1.4 1997/12/04 23:52:19 mromberg Exp $
+// $Id: cpumeter.cc,v 1.8 1999/02/02 00:59:30 mromberg Exp $
 //
 #include "cpumeter.h"
 #include "xosview.h"
@@ -12,7 +12,7 @@
 #include <stdlib.h>
 
 CPUMeter::CPUMeter( XOSView *parent )
-: FieldMeterDecay( parent, 5, "CPU", "USR/NICE/SYS/INT/FREE" ){
+: FieldMeterGraph( parent, 5, "CPU", "USR/NICE/SYS/INT/FREE" ){
   for ( int i = 0 ; i < 2 ; i++ )
     for ( int j = 0 ; j < 5 ; j++ )
       cputime_[i][j] = 0;
@@ -23,7 +23,7 @@ CPUMeter::~CPUMeter( void ){
 }
 
 void CPUMeter::checkResources( void ){
-  FieldMeterDecay::checkResources();
+  FieldMeterGraph::checkResources();
 
   setfieldcolor( 0, parent_->getResource( "cpuUserColor" ) );
   setfieldcolor( 1, parent_->getResource( "cpuNiceColor" ) );
@@ -31,7 +31,8 @@ void CPUMeter::checkResources( void ){
   setfieldcolor( 3, parent_->getResource( "cpuInterruptColor" ) );
   setfieldcolor( 4, parent_->getResource( "cpuFreeColor" ) );
   priority_ = atoi (parent_->getResource( "cpuPriority" ) );
-  dodecay_ = !strcmp (parent_->getResource( "cpuDecay" ), "True" );
+  dodecay_ = parent_->isResourceTrue( "cpuDecay" );
+  useGraph_ = parent_->isResourceTrue( "cpuGraph" );
   SetUsedFormat( parent_->getResource( "cpuUsedFormat" ) );
 }
 
