@@ -4,19 +4,19 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: cpumeter.h,v 1.2 1996/08/14 06:20:42 mromberg Exp $
+// $Id: cpumeter.h,v 1.4 1999/01/23 22:20:40 mromberg Exp $
 //
 #ifndef _CPUMETER_H_
 #define _CPUMETER_H_
 
-#include "fieldmeterdecay.h"
+#include "fieldmetergraph.h"
 
-class CPUMeter : public FieldMeterDecay {
+class CPUMeter : public FieldMeterGraph {
 public:
   CPUMeter( XOSView *parent );
   ~CPUMeter( void );
 
-  const char *name( void ) { return "CPUMeter"; }
+  const char *name( void ) const { return "CPUMeter"; }
   void checkevent( void );
 
   void checkResources(void);
