@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: memmeter.cc,v 1.7 1997/12/06 01:04:40 mromberg Exp $
+// $Id: memmeter.cc,v 1.12 1999/01/31 20:18:49 bgrayson Exp $
 //
 #include "memmeter.h"
 #include "xosview.h"
@@ -15,9 +15,9 @@ MemMeter::MemMeter( XOSView *parent )
 : FieldMeterDecay( parent, 4, "MEM", "TEXT/USED/OTHER/FREE" ){
   struct pst_static pststatic;
 
-  pstat_getstatic( &pststatic, sizeof( struct pst_static ), 1, 0 );
+  pstat_getstatic( &pststatic, sizeof( struct pst_static ), 1, 0);
   total_ = pststatic.physical_memory;
-  _pageSize = pststatic.page_size;
+  _pageSize = (int)pststatic.page_size;
 
   stats_ = new struct pst_status[pststatic.max_proc];
 }
@@ -30,7 +30,7 @@ void MemMeter::checkResources( void ){
   setfieldcolor( 2, parent_->getResource( "memOtherColor" ) );
   setfieldcolor( 3, parent_->getResource( "memFreeColor" ) );
   priority_ = atoi (parent_->getResource( "memPriority" ) );
-  dodecay_ = !strcmp (parent_->getResource( "memDecay" ), "True" );
+  dodecay_ = parent_->isResourceTrue( "memDecay" );
   SetUsedFormat( parent_->getResource( "memUsedFormat" ) );
 }
 
