@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: memmeter.h,v 1.3 1997/12/06 01:04:41 mromberg Exp $
+// $Id: memmeter.h,v 1.4 1999/01/23 22:20:40 mromberg Exp $
 //
 #ifndef _MEMMETER_H_
 #define _MEMMETER_H_
@@ -17,7 +17,7 @@ public:
   MemMeter( XOSView *parent );
   ~MemMeter( void );
 
-  const char *name( void ) { return "MemMeter"; }  
+  const char *name( void ) const { return "MemMeter"; }  
   void checkevent( void );
 
   void checkResources(void);
