@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: pagemeter.cc,v 1.3 1997/12/04 23:52:21 mromberg Exp $
+// $Id: pagemeter.cc,v 1.5 1999/01/31 20:18:49 bgrayson Exp $
 //
 #include "pagemeter.h"
 #include "xosview.h"
@@ -32,7 +32,7 @@ void PageMeter::checkResources( void ){
   setfieldcolor( 2, parent_->getResource( "pageIdleColor" ) );
   priority_ = atoi (parent_->getResource( "pagePriority" ) );
   maxspeed_ *= priority_ / 10.0;
-  dodecay_ = !strcmp (parent_->getResource( "pageDecay" ), "True" );
+  dodecay_ = parent_->isResourceTrue( "pageDecay" );
   SetUsedFormat( parent_->getResource( "pageUsedFormat" ) );
 }
 
