@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: swapmeter.cc,v 1.6 1997/12/06 01:04:41 mromberg Exp $
+// $Id: swapmeter.cc,v 1.9 1999/02/01 17:28:49 mromberg Exp $
 //
 #include "swapmeter.h"
 #include "xosview.h"
@@ -25,8 +25,8 @@ void SwapMeter::checkResources( void ){
 
   setfieldcolor( 0, parent_->getResource( "swapUsedColor" ) );
   setfieldcolor( 1, parent_->getResource( "swapFreeColor" ) );
-  priority_ = atoi (parent_->getResource( "swapPriority" ) );
-  dodecay_ = !strcmp (parent_->getResource( "swapDecay" ), "True" );
+  priority_ = atoi(parent_->getResource( "swapPriority" ) );
+  dodecay_ = parent_->isResourceTrue( "swapDecay" );
   SetUsedFormat( parent_->getResource( "swapUsedFormat" ) );
 }
 
