@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: swapmeter.h,v 1.2 1996/08/14 06:20:49 mromberg Exp $
+// $Id: swapmeter.h,v 1.3 1999/01/23 22:20:40 mromberg Exp $
 //
 #ifndef _SWAPMETER_H_
 #define _SWAPMETER_H_
@@ -16,7 +16,7 @@ public:
   SwapMeter( XOSView *parent );
   ~SwapMeter( void );
 
-  const char *name( void ) { return "SwapMeter"; }  
+  const char *name( void ) const { return "SwapMeter"; }  
   void checkevent( void );
   void checkResources(void);
 
