@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: MeterMaker.cc,v 1.13 1998/03/07 21:47:31 mromberg Exp $
+// $Id: MeterMaker.cc,v 1.18 1999/11/12 05:13:22 romberg Exp $
 //
 #include "MeterMaker.h"
 #include "xosview.h"
@@ -18,6 +18,8 @@
 #include "serialmeter.h"
 #include "loadmeter.h"
 #include "btrymeter.h"
+#include "diskmeter.h"
+#include "raidmeter.h"
 
 #include <stdlib.h>
 
@@ -50,11 +52,16 @@ void MeterMaker::makeMeters(void){
   if (_xos->isResourceTrue("net"))
     push(new NetMeter(_xos, atof(_xos->getResource("netBandwidth"))));
 
+  if (_xos->isResourceTrue("disk"))
+      push(new DiskMeter(_xos, atof(_xos->getResource("diskBandwidth"))));
+
   // check for the serial meters.
+#ifndef __mc68000__
   for (int i = 0 ; i < SerialMeter::numDevices() ; i++)
-    if (strcmp(_xos->getResource(
-      SerialMeter::getResourceName((SerialMeter::Device)i)), "False"))
-      push(new SerialMeter(_xos, (SerialMeter::Device)i));
+    if (_xos->isResourceTrue(SerialMeter::getResourceName(
+      (SerialMeter::Device)i)))
+        push(new SerialMeter(_xos, (SerialMeter::Device)i));
+#endif
 
   // check for the interrupt meter
   if (_xos->isResourceTrue("interrupts")) {
@@ -64,6 +71,14 @@ void MeterMaker::makeMeters(void){
       push(new IntMeter(_xos, i));
   }
 
+  // check for the battery meter
   if (_xos->isResourceTrue("battery"))
     push(new BtryMeter(_xos));
+
+  // check for the RAID meter
+  if (_xos->isResourceTrue("RAID")){
+    int RAIDCount = atoi(_xos->getResource("RAIDdevicecount"));
+    for (int i = 0 ; i < RAIDCount ; i++)
+      push(new RAIDMeter(_xos, i));
+  }
 }
