@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: btrymeter.cc,v 1.3 1997/12/02 20:03:41 bgrayson Exp $
+// $Id: btrymeter.cc,v 1.5 1999/01/23 18:34:26 mromberg Exp $
 //
 #include "btrymeter.h"
 #include "xosview.h"
@@ -14,7 +14,7 @@
 static const char APMFILENAME[] = "/proc/apm";
 
 BtryMeter::BtryMeter( XOSView *parent )
-  : FieldMeter( parent, 2, "BTRY", "AVAIL/USED", 1, 0 ){
+  : FieldMeter( parent, 2, "BTRY", "AVAIL/USED", 1, 1, 0 ){
 }
 
 BtryMeter::~BtryMeter( void ){
@@ -23,8 +23,8 @@ BtryMeter::~BtryMeter( void ){
 void BtryMeter::checkResources( void ){
   FieldMeter::checkResources();
 
-  setfieldcolor( 0, parent_->getResource( "batteryUsedColor" ) );
-  setfieldcolor( 1, parent_->getResource( "batteryLeftColor" ) );
+  setfieldcolor( 0, parent_->getResource( "batteryLeftColor" ) );
+  setfieldcolor( 1, parent_->getResource( "batteryUsedColor" ) );
 
   priority_ = atoi (parent_->getResource( "batteryPriority" ) );
   SetUsedFormat(parent_->getResource( "batteryUsedFormat" ) );
