@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: cpumeter.cc,v 1.4 1997/12/02 20:03:42 bgrayson Exp $
+// $Id: cpumeter.cc,v 1.9 1999/02/24 22:16:20 romberg Exp $
 //
 #include "cpumeter.h"
 #include "xosview.h"
@@ -17,7 +17,7 @@
 static const char STATFILENAME[] = "/proc/stat";
 
 CPUMeter::CPUMeter(XOSView *parent, const char *cpuID)
-: FieldMeterDecay( parent, 4, toUpper(cpuID), "USR/NICE/SYS/FREE" ) {
+: FieldMeterGraph( parent, 4, toUpper(cpuID), "USR/NICE/SYS/FREE" ) {
   _lineNum = findLine(cpuID);
   for ( int i = 0 ; i < 2 ; i++ )
     for ( int j = 0 ; j < 4 ; j++ )
@@ -30,14 +30,15 @@ CPUMeter::~CPUMeter( void ){
 }
 
 void CPUMeter::checkResources( void ){
-  FieldMeterDecay::checkResources();
+  FieldMeterGraph::checkResources();
 
   setfieldcolor( 0, parent_->getResource( "cpuUserColor" ) );
   setfieldcolor( 1, parent_->getResource( "cpuNiceColor" ) );
   setfieldcolor( 2, parent_->getResource( "cpuSystemColor" ) );
   setfieldcolor( 3, parent_->getResource( "cpuFreeColor" ) );
   priority_ = atoi (parent_->getResource( "cpuPriority" ) );
-  dodecay_ = !strcmp (parent_->getResource( "cpuDecay" ), "True" );
+  dodecay_ = parent_->isResourceTrue( "cpuDecay" );
+  useGraph_ = parent_->isResourceTrue( "cpuGraph" );
   SetUsedFormat (parent_->getResource("cpuUsedFormat"));
 }
 
@@ -48,7 +49,7 @@ void CPUMeter::checkevent( void ){
 
 void CPUMeter::getcputime( void ){
   total_ = 0;
-  char tmp[256];
+  char tmp[1024];
   ifstream stats( STATFILENAME );
 
   if ( !stats ){
@@ -58,7 +59,7 @@ void CPUMeter::getcputime( void ){
 
   // read until we are at the right line.
   for (int i = 0 ; i < _lineNum ; i++)
-    stats.getline(tmp, 256);
+    stats.getline(tmp, 1024);
 
   stats >>tmp >>cputime_[cpuindex_][0]  
 	      >>cputime_[cpuindex_][1]  
@@ -86,9 +87,9 @@ int CPUMeter::findLine(const char *cpuID){
   }
 
   int line = -1;
-  char buf[256];
+  char buf[1024];
   while (!stats.eof()){
-    stats.getline(buf, 256);
+    stats.getline(buf, 1024);
     if (!stats.eof()){
       line++;
       if (!strncmp(cpuID, buf, strlen(cpuID)) && buf[strlen(cpuID)] == ' ')
@@ -111,9 +112,9 @@ int CPUMeter::countCPUs(void){
   }
 
   int cpuCount = 0;
-  char buf[256];
+  char buf[1024];
   while (!stats.eof()){
-    stats.getline(buf, 256);
+    stats.getline(buf, 1024);
     if (!stats.eof()){
       if (!strncmp(buf, "cpu", 3) && buf[3] != ' ')
           cpuCount++;
@@ -136,8 +137,8 @@ const char *CPUMeter::cpuStr(int num){
 }
 
 const char *CPUMeter::toUpper(const char *str){
-  static char buffer[256];
-  strcpy(buffer, str);
+  static char buffer[1024];
+  strncpy(buffer, str, 1024);
   for (char *tmp = buffer ; *tmp != '\0' ; tmp++)
     *tmp = toupper(*tmp);
 
