@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: intmeter.cc,v 1.8 1998/05/30 21:56:27 mromberg Exp $
+// $Id: intmeter.cc,v 1.10 1998/10/03 23:35:24 mromberg Exp $
 //
 #include "intmeter.h"
 #include "xosview.h"
@@ -12,6 +12,9 @@
 #include <fstream.h>
 #include <strstream.h>
 #include <stdlib.h>
+#ifdef __alpha__
+#include <asm/irq.h>
+#endif 
 
 
 static const char *INTFILE     = "/proc/interrupts";
@@ -26,8 +29,16 @@ IntMeter::IntMeter( XOSView *parent, int cpu)
  }
  else {
    _old = false;
+#ifdef __alpha__
+   ostrstream os;
+   setNumBits(NR_IRQS);
+   os << "INTs (0-" << (NR_IRQS-1) << ")" << ends;
+   legend(os.str());
+   delete[] os.str();
+#else    
    setNumBits(24);
    legend("INTs (0-23)");
+#endif
  }
 
   for ( int i = 0 ; i < numBits() ; i++ )
