@@ -6,7 +6,7 @@
 //  Most of this code was written by Werner Fink <werner@suse.de>.
 //  Only small changes were made on my part (M.R.)
 //
-// $Id: loadmeter.cc,v 1.3 1997/12/02 20:03:42 bgrayson Exp $
+// $Id: loadmeter.cc,v 1.8 1999/11/06 22:48:17 romberg Exp $
 //
 #include "loadmeter.h"
 #include "xosview.h"
@@ -16,26 +16,30 @@
 static const char LOADFILENAME[] = "/proc/loadavg";
 
 LoadMeter::LoadMeter( XOSView *parent )
-  : FieldMeterDecay( parent, 2, "LOAD", "PROCS/MIN", 1, 0 ){
-
+  : FieldMeterGraph( parent, 2, "LOAD", "PROCS/MIN", 1, 1, 0 ){
+  lastalarmstate = -1;
+  total_ = 2.0;
 }
 
 LoadMeter::~LoadMeter( void ){
 }
 
 void LoadMeter::checkResources( void ){
-  FieldMeterDecay::checkResources();
+  FieldMeterGraph::checkResources();
 
-  warnloadcol_ = parent_->allocColor(parent_->getResource( "loadWarnColor" ));
   procloadcol_ = parent_->allocColor(parent_->getResource( "loadProcColor" ));
+  warnloadcol_ = parent_->allocColor(parent_->getResource( "loadWarnColor" ));
+  critloadcol_ = parent_->allocColor(parent_->getResource( "loadCritColor" ));
 
   setfieldcolor( 0, procloadcol_ );
   setfieldcolor( 1, parent_->getResource( "loadIdleColor" ) );
   priority_ = atoi (parent_->getResource( "loadPriority" ) );
-  dodecay_ = !strcmp (parent_->getResource( "loadDecay" ), "True" );
+  useGraph_ = parent_->isResourceTrue( "loadGraph" );
+  dodecay_ = parent_->isResourceTrue( "loadDecay" );
   SetUsedFormat (parent_->getResource("loadUsedFormat"));
 
-  alarmThreshold = atoi (parent_->getResource("loadAlarmThreshold"));
+  warnThreshold = atoi (parent_->getResource("loadWarnThreshold"));
+  critThreshold = atoi (parent_->getResource("loadCritThreshold"));
 
 
   if (dodecay_){
@@ -54,7 +58,6 @@ void LoadMeter::checkResources( void ){
 
 void LoadMeter::checkevent( void ){
   getloadinfo();
-
   drawfields();
 }
 
@@ -68,21 +71,34 @@ void LoadMeter::getloadinfo( void ){
     return;
   }
 
-  loadinfo >>fields_[0];
+  loadinfo >> fields_[0];
 
-  if ( fields_[0] > alarmThreshold ) {
-    if (total_ == alarmThreshold ) {
-      setfieldcolor( 0, warnloadcol_ );
-      if (dolegends_) drawlegend();
-    }
-    total_ = fields_[1] = 20;
-  } else {
-    if (total_ == 20 ) {
-      setfieldcolor( 0, procloadcol_ );
-      if (dolegends_) drawlegend();
-    }
-    total_ = fields_[1] = alarmThreshold;
+  if ( fields_[0] <  warnThreshold ) alarmstate = 0;
+  else
+  if ( fields_[0] >= critThreshold ) alarmstate = 2;
+  else
+  /* if fields_[0] >= warnThreshold */ alarmstate = 1;
+  
+  if ( alarmstate != lastalarmstate ){
+    if ( alarmstate == 0 ) setfieldcolor( 0, procloadcol_ );
+    else
+    if ( alarmstate == 1 ) setfieldcolor( 0, warnloadcol_ );
+    else
+    /* if alarmstate == 2 */ setfieldcolor( 0, critloadcol_ );
+    if (dolegends_) drawlegend();
+    lastalarmstate = alarmstate;
   }
+  
+  if ( fields_[0]*5.0<total_ )
+    total_ = fields_[0];
+  else
+  if ( fields_[0]>total_ )
+    total_ = fields_[0]*5.0;
+      
+  if ( total_ < 1.0)
+    total_ = 1.0;
+    
+  fields_[1] = (float) (total_ - fields_[0]);
 
-  setUsed(fields_[0], total_);
+  setUsed(fields_[0], (float) 1.0);
 }
