@@ -6,16 +6,16 @@
 //  Most of this code was written by Werner Fink <werner@suse.de>
 //  Only small changes were made on my part (M.R.)
 //
-// $Id: loadmeter.h,v 1.3 1996/11/24 05:07:55 bgrayson Exp $
+// $Id: loadmeter.h,v 1.5 1999/11/06 22:48:17 romberg Exp $
 //
 #ifndef _LOADMETER_H_
 #define _LOADMETER_H_
 
 
-#include "fieldmeterdecay.h"
+#include "fieldmetergraph.h"
 
 
-class LoadMeter : public FieldMeterDecay {
+class LoadMeter : public FieldMeterGraph {
 public:
   LoadMeter( XOSView *parent );
   ~LoadMeter( void );
@@ -27,9 +27,9 @@ public:
 protected:
 
   void getloadinfo( void );
-  unsigned long procloadcol_, warnloadcol_;
+  unsigned long procloadcol_, warnloadcol_, critloadcol_;
 private:
-  int alarmThreshold;
+  int warnThreshold, critThreshold, alarmstate, lastalarmstate;
 };
 
 
