@@ -3,7 +3,7 @@
 //
 //  This file may be distributed under terms of the GPL
 //
-// $Id: memmeter.cc,v 1.7 1997/12/02 20:03:42 bgrayson Exp $
+// $Id: memmeter.cc,v 1.11 1999/11/06 22:48:17 romberg Exp $
 //
 #include "memmeter.h"
 #include "xosview.h"
@@ -15,7 +15,7 @@ static const char MEMFILENAME[] = "/proc/meminfo";
 static const char MEMSTATFNAME[] = "/proc/memstat";
 
 MemMeter::MemMeter( XOSView *parent )
-: FieldMeterDecay( parent, 4, "MEM", "USED+SHAR/BUFF/CACHE/FREE" ){
+: FieldMeterGraph( parent, 4, "MEM", "USED+SHAR/BUFF/CACHE/FREE" ){
   _shAdj = -1;
 
   // Check and see if the memstat module has been loaded
@@ -37,7 +37,7 @@ MemMeter::~MemMeter( void ){
 }
 
 void MemMeter::checkResources( void ){
-  FieldMeterDecay::checkResources();
+  FieldMeterGraph::checkResources();
 
   setfieldcolor( 0, parent_->getResource( "memUsedColor" ) );
   if (_shAdj == 0)
@@ -46,24 +46,38 @@ void MemMeter::checkResources( void ){
   setfieldcolor( 3 + _shAdj, parent_->getResource( "memCacheColor" ) );
   setfieldcolor( 4 + _shAdj, parent_->getResource( "memFreeColor" ) );
   priority_ = atoi (parent_->getResource( "memPriority" ) );
-  dodecay_ = !strcmp (parent_->getResource( "memDecay" ), "True" );
+  dodecay_ = parent_->isResourceTrue( "memDecay" );
+  useGraph_ = parent_->isResourceTrue( "memGraph" );
   SetUsedFormat (parent_->getResource("memUsedFormat"));
 }
 
 void MemMeter::checkevent( void ){
   getmeminfo();
+  /* for debugging (see below) 
+  printf("t %4.1f used %4.1f share %4.1f buffer %4.1f cache %4.1f free %4.1f\n",
+         total_/1024.0/1024.0,
+         fields_[0]/1024.0/1024.0, fields_[1]/1024.0/1024.0,
+	 fields_[2]/1024.0/1024.0, fields_[3]/1024.0/1024.0,
+	 fields_[4]/1024.0/1024.0);
+  */
   drawfields();
 }
 
+// FIXME: /proc/memstat and /proc/meminfo don't seem to correspond
+// maybe it is time to fix this in the kernel and get real infos ...
+
 void MemMeter::getmeminfo( void ){
   getmemstat(MEMFILENAME, _MIlineInfos, _numMIlineInfos);
   if (_shAdj == 0)
     getmemstat(MEMSTATFNAME, _MSlineInfos, _numMSlineInfos);
 
-  fields_[0] = total_ - fields_[4 + _shAdj] - fields_[3 + _shAdj] 
-    - fields_[2 + _shAdj];
-  if (_shAdj == 0)
-    fields_[0] -= fields_[1];
+  if (_shAdj == 0){
+    fields_[3] -= fields_[1]; // cache size seems to contain shared size !?
+                              // without this fix "used" sometimes gets < 0 !
+    fields_[0] = total_ - fields_[4] - fields_[3] - fields_[2] - fields_[1];
+  }else{
+    fields_[0] = total_ - fields_[3] - fields_[2] - fields_[1];
+  }
 
   if (total_)
     FieldMeterDecay::setUsed (total_ - fields_[4 + _shAdj], total_);
