@@ -7,7 +7,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: netmeter.cc,v 1.11 1998/05/19 05:42:12 mromberg Exp $
+// $Id: netmeter.cc,v 1.19 1999/11/12 04:32:32 romberg Exp $
 //
 
 //-----------------------------------------------------------------------
@@ -43,10 +43,11 @@
 #include <errno.h>
 
 NetMeter::NetMeter( XOSView *parent, float max )
-  : FieldMeterDecay( parent, 3, "NET", "IN/OUT/IDLE" ){
+  : FieldMeterGraph( parent, 3, "NET", "IN/OUT/IDLE" ){
   _timer.start();
   maxpackets_ = max;
   _lastBytesIn = _lastBytesOut = 0;
+  _usechains = false;
 
   checkOSVersion();
 }
@@ -63,31 +64,55 @@ void NetMeter::checkOSVersion(void)
         cerr <<"Can not open file : " << "/proc/sys/kernel/osrelease" <<endl;
         exit(1);
         }
-
+    
     int major, minor;
     _bytesInDev = 0;
     ifs >> major;
     ifs.ignore(1);
     ifs >> minor;
     ifs.ignore(1);
-
+    
     if (major > 2 || (major == 2 && minor >= 1))
         {
-        _netfilename = "/proc/net/dev";
-        _bytesInDev = 1;
+	// check presence of iacct and oacct chains
+        ifstream chains("/proc/net/ip_fwchains");
+	int n = 0;
+	char buf[1024];
+        
+        while (chains && !chains.eof())
+            {
+            chains >> buf;
+            chains.ignore(1024, '\n');
+            
+            if (!strncmp(buf, "iacct", 5))
+                n |= 1;
+            if (!strncmp(buf, "oacct", 5))
+                n |= 2;
+            }
+
+	if (n == 3)
+            {
+            _netfilename = "/proc/net/ip_fwchains";
+            _usechains = true;
+            }
+	else
+            _netfilename = "/proc/net/dev";
+
+	_bytesInDev = 1;
         }
     else
         _netfilename = "/proc/net/ip_acct";
     }
 
 void NetMeter::checkResources( void ){
-  FieldMeterDecay::checkResources();
+  FieldMeterGraph::checkResources();
 
   setfieldcolor( 0, parent_->getResource( "netInColor" ) );
   setfieldcolor( 1, parent_->getResource( "netOutColor" ) );
   setfieldcolor( 2, parent_->getResource( "netBackground" ) );
   priority_ = atoi (parent_->getResource( "netPriority" ) );
-  dodecay_ = !strcmp (parent_->getResource( "netDecay" ), "True" );
+  useGraph_ = parent_->isResourceTrue( "netGraph" );
+  dodecay_ = parent_->isResourceTrue( "netDecay" );
   SetUsedFormat (parent_->getResource("netUsedFormat"));
 
   _ipsock = socket(AF_INET, SOCK_DGRAM, 0);
@@ -119,28 +144,44 @@ void NetMeter::checkeventNew(void)
 
     unsigned long in, out, ig;
     unsigned long totin = 0, totout = 0;
+    char buf[1024];
     
     fields_[2] = maxpackets_;     // assume no
     fields_[0] = fields_[1] = 0;  // network activity
 
     _timer.stop();
 
-    ifs.ignore(1024, '\n');
-    ifs.ignore(1024, '\n');
-
-    while (!ifs.eof())
+    if (_usechains)
+      while (!ifs.eof())
         {
-        ifs.ignore(1024, ':');
-        ifs >> in >> ig >> ig >> ig >> ig >> ig >> ig >> ig >> out;
+	ifs >> buf;
 
-        if (!ifs.eof())
-            {
-            totin += in;
-            totout += out;
-            }
+	if (!strncmp(buf, "iacct", 5)) 
+	  ifs >> buf >> buf >> ig >> ig >> ig >> ig >> ig >> ig >> totin;
+	else if (!strncmp(buf, "oacct", 5)) 
+	  ifs >> buf >> buf >> ig >> ig >> ig >> ig >> ig >> ig >> totout;
 
-        ifs.ignore(1024, '\n');
+	ifs.ignore(1024, '\n');
         }
+    else
+        {
+	  ifs.ignore(1024, '\n');
+	  ifs.ignore(1024, '\n');
+
+	  while (!ifs.eof())
+	      {
+	      ifs.ignore(1024, ':');
+	      ifs >> in >> ig >> ig >> ig >> ig >> ig >> ig >> ig >> out;
+
+	      if (!ifs.eof())
+		  {
+		  totin += in;
+		  totout += out;
+		  }
+
+	      ifs.ignore(1024, '\n');
+	      }
+	}
 
     float t = 1000000.0 / _timer.report();
 
@@ -204,7 +245,7 @@ void NetMeter::checkeventOld(void)
         if (!ifs.eof())
             {
             struct ifreq *ifr = ifc.ifc_req;
-            for (register i = ifc.ifc_len / sizeof(struct ifreq); 
+            for (int i = ifc.ifc_len / sizeof(struct ifreq);
                  --i >= 0; ifr++) 
                 {
                 unsigned long adr = ntohl(
