@@ -4,17 +4,17 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: netmeter.h,v 1.3 1998/05/16 20:31:54 mromberg Exp $
+// $Id: netmeter.h,v 1.5 1999/11/07 20:22:11 romberg Exp $
 //
 #ifndef _NETMETER_H_
 #define _NETMETER_H_
 
-#include "fieldmeterdecay.h"
+#include "fieldmetergraph.h"
 #include "timer.h"
 
 class Host;
 
-class NetMeter : public FieldMeterDecay {
+class NetMeter : public FieldMeterGraph {
 public:
   NetMeter(XOSView *parent, float max);
   ~NetMeter( void );
@@ -31,6 +31,7 @@ private:
   Timer _timer;
   unsigned long _lastBytesIn, _lastBytesOut;
   char *_netfilename;
+  bool _usechains;
   int _bytesInDev;
 
   void adjust(void);
