@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: pagemeter.cc,v 1.3 1997/12/02 20:03:43 bgrayson Exp $
+// $Id: pagemeter.cc,v 1.7 1999/02/24 22:28:18 romberg Exp $
 //
 #include "pagemeter.h"
 #include "xosview.h"
@@ -16,7 +16,7 @@ static const char STATFILENAME[] = "/proc/stat";
 
 
 PageMeter::PageMeter( XOSView *parent, float max )
-  : FieldMeterDecay( parent, 3, "PAGE", "IN/OUT/IDLE" ){
+  : FieldMeterGraph( parent, 3, "PAGE", "IN/OUT/IDLE" ){
   for ( int i = 0 ; i < 2 ; i++ )
     for ( int j = 0 ; j < 2 ; j++ )
       pageinfo_[j][i] = 0;
@@ -29,14 +29,15 @@ PageMeter::~PageMeter( void ){
 }
 
 void PageMeter::checkResources( void ){
-  FieldMeterDecay::checkResources();
+  FieldMeterGraph::checkResources();
 
   setfieldcolor( 0, parent_->getResource( "pageInColor" ) );
   setfieldcolor( 1, parent_->getResource( "pageOutColor" ) );
   setfieldcolor( 2, parent_->getResource( "pageIdleColor" ) );
   priority_ = atoi (parent_->getResource( "pagePriority" ) );
   maxspeed_ *= priority_ / 10.0;
-  dodecay_ = !strcmp (parent_->getResource( "pageDecay" ), "True" );
+  dodecay_ = parent_->isResourceTrue( "pageDecay" );
+  useGraph_ = parent_->isResourceTrue( "pageGraph" );
   SetUsedFormat (parent_->getResource("pageUsedFormat"));
 }
 
@@ -47,7 +48,7 @@ void PageMeter::checkevent( void ){
 
 void PageMeter::getpageinfo( void ){
   total_ = 0;
-  char buf[256];
+  char buf[1024];
   ifstream stats( STATFILENAME );
 
   if ( !stats ){
@@ -57,7 +58,7 @@ void PageMeter::getpageinfo( void ){
 
   do {
     stats >>buf;
-  } while (strcmp(buf, "swap"));
+  } while (strncasecmp(buf, "swap", 5));
 	  
   stats >>pageinfo_[pageindex_][0] >>pageinfo_[pageindex_][1];
 
@@ -81,42 +82,3 @@ void PageMeter::getpageinfo( void ){
   setUsed (total_ - fields_[2], maxspeed_);
   pageindex_ = (pageindex_ + 1) % 2;
 }
-
-
-// void PageMeter::getpageinfo( void ){
-//   total_ = 0;
-//   char buf[256];
-//   ifstream stats( STATFILENAME );
-
-//   if ( !stats ){
-//     cerr <<"Cannot open file : " <<STATFILENAME <<endl;
-//     exit( 1 );
-//   }
-
-//   stats.getline( buf, 256 );
-//   stats.getline( buf, 256 );
-//   stats.getline( buf, 256 );
-
-//   stats >>buf >>pageinfo_[pageindex_][0]
-// 	      >>pageinfo_[pageindex_][1];
-
-//   int oldindex = (pageindex_+1)%2;
-  
-//   for ( int i = 0; i < 2; i++ ) {
-//     if ( pageinfo_[oldindex][i] == 0 )
-//       pageinfo_[oldindex][i] = pageinfo_[pageindex_][i];
-
-//     fields_[i] = pageinfo_[pageindex_][i] - pageinfo_[oldindex][i];
-//     total_ += fields_[i];
-//   }
-
-//   if ( total_ > maxspeed_ )
-//     fields_[2] = 0.0;
-//   else {
-//     fields_[2] = maxspeed_ - total_;
-//     total_ = maxspeed_;
-//   }
-
-//   "Ack.  Use setUsed instead.  bgrayson"  used( (int)((100 * (total_ - fields_[2])) / maxspeed_) );
-//   pageindex_ = (pageindex_ + 1) % 2;
-// }
