@@ -4,7 +4,7 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: serialmeter.cc,v 1.6 1997/11/18 02:54:20 mromberg Exp $
+// $Id: serialmeter.cc,v 1.9 1998/10/04 18:16:38 mromberg Exp $
 //
 
 //
@@ -18,13 +18,28 @@
 #include <stdlib.h>
 #include <strstream.h>
 
+// This should go away after types.h gets fixed in the kernel.
+#ifdef __alpha__
+typedef unsigned char u8;
+typedef signed short s16;
+typedef unsigned short u16;
+typedef signed int s32;
+typedef unsigned int u32;
+typedef signed long long s64;
+typedef unsigned long long u64;
+#endif
+
 #include <unistd.h>
 #if defined(GNULIBC) || defined(__GLIBC__)
 #include <sys/io.h>
+#ifndef __alpha__
 #include <sys/perm.h>
+#endif
 #else
+#ifndef __alpha__
 #include <asm/io.h>
 #endif
+#endif
 #include <linux/serial.h>
 #include <linux/serial_reg.h>
 
@@ -100,7 +115,7 @@ unsigned short int SerialMeter::getPortBase(Device dev) const {
 
   const char* res = parent_->getResource(getResourceName(dev));
 
-  if (!strcasecmp(res, "True")){ // Autodetect portbase.
+  if (!strncasecmp(res, "True", 5)){ // Autodetect portbase.
     int fd;
     struct serial_struct serinfo;
 
