@@ -4,24 +4,26 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: main.cc,v 1.4 1996/12/04 04:02:34 bgrayson Exp $
+// $Id: main.cc,v 1.6 1999/11/05 05:39:03 romberg Exp $
 //
 #include "general.h"
 #include "xosview.h"
 
-CVSID("$Id: main.cc,v 1.4 1996/12/04 04:02:34 bgrayson Exp $");
+CVSID("$Id: main.cc,v 1.6 1999/11/05 05:39:03 romberg Exp $");
 
-main( int argc, char *argv[] ) {
+int main( int argc, char *argv[] ) {
   /*  Icky.  Need to check for -name option here.  */
   char** argp = argv;
   char* instanceName = "xosview";	// Default value.
   while (argp && *argp)
   {
-    if (!strcmp(*argp, "-name"))
+    if (!strncmp(*argp, "-name", 6))
       instanceName = argp[1];
     argp++;
   }  //  instanceName will end up pointing to the last such -name option.
   XOSView xosview( instanceName, argc, argv );
 
   xosview.run();
+
+  return 0;
 }
