@@ -4,21 +4,22 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: meter.cc,v 1.3 1996/11/19 04:14:53 bgrayson Exp $
+// $Id: meter.cc,v 1.9 1999/11/12 05:13:21 romberg Exp $
 //
 #include "general.h"
 #include "meter.h"
 #include "xosview.h"
 
-CVSID("$Id: meter.cc,v 1.3 1996/11/19 04:14:53 bgrayson Exp $");
+CVSID("$Id: meter.cc,v 1.9 1999/11/12 05:13:21 romberg Exp $");
 CVSID_DOT_H(METER_H_CVSID);
 
 Meter::Meter( XOSView *parent, const char *title, const char *legend, 
-              int dolegends, int dousedlegends ) {
+              int docaptions, int dolegends, int dousedlegends ) {
   title_ = legend_ = NULL;
   Meter::title( title );
   Meter::legend( legend );
   parent_ = parent;
+  docaptions_ = docaptions;
   dolegends_ = dolegends;
   dousedlegends_ = dousedlegends;
   priority_ = 1;
@@ -38,21 +39,26 @@ void Meter::checkResources( void ){
 
 void Meter::title( const char *title ){
   delete[] title_;
-  title_ = new char[strlen( title ) + 1];
-  strcpy( title_, title );
+  int len = strlen(title);
+  title_ = new char[len + 1];
+  strncpy( title_, title, len );
+  title_[len] = '\0'; // strncpy() will not null terminate if s2 > len
 }
 
 void Meter::legend( const char *legend ){
   delete[] legend_;
-  legend_ = new char[strlen( legend ) + 1];
-  strcpy( legend_, legend );
+  int len = strlen(legend);
+  legend_ = new char[len + 1];
+  strncpy( legend_, legend, len );
+  legend_[len] = '\0'; // strncpy() will not null terminate if s2 > len
 }
 
 void Meter::resize( int x, int y, int width, int height ){
   x_ = x;
   y_ = y;
-  width_ = width;
-  height_ = height;
+  width_ = (width>=0) ? width : 0;    // fix for cosmetical bug:
+  height_ = (height>=0) ? height : 0; // beware of values < 0 !
+  width_ &= ~1;                       // only allow even width_ values
 }
 
 
