@@ -4,12 +4,12 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: meter.h,v 1.5 1998/02/12 05:00:08 bgrayson Exp $
+// $Id: meter.h,v 1.7 1999/02/19 09:44:26 mcnab Exp $
 //
 #ifndef _METER_H_
 #define _METER_H_
 
-#define METER_H_CVSID "$Id: meter.h,v 1.5 1998/02/12 05:00:08 bgrayson Exp $"
+#define METER_H_CVSID "$Id: meter.h,v 1.7 1999/02/19 09:44:26 mcnab Exp $"
 
 #include <stdio.h>
 #include "xosview.h"	//  To grab MAX_SAMPLES_PER_SECOND.
@@ -19,7 +19,7 @@ class XOSView;
 class Meter {
 public:
   Meter( XOSView *parent, const char *title = "", const char *legend ="", 
-	 int dolegends = 0, int dousedlegends = 0 );
+	 int docaptions = 0, int dolegends = 0, int dousedlegends = 0 );
   virtual ~Meter( void );
 
   virtual const char *name( void ) const { return "Meter"; }
@@ -30,6 +30,7 @@ public:
   const char *title( void ) { return title_; }
   void legend( const char *legend );
   const char *legend( void ) { return legend_; }
+  void docaptions( int val ) { docaptions_ = val; }
   void dolegends( int val ) { dolegends_ = val; }
   void dousedlegends( int val ) { dousedlegends_ = val; }
   int requestevent( void ){ 
@@ -43,11 +44,16 @@ public:
     return !rval;
   }
 
+  int getX() const { return x_; }
+  int getY() const { return y_; }
+  int getWidth() const { return width_; }
+  int getHeight() const { return height_; }
+
   virtual void checkResources( void );
 
 protected:
   XOSView *parent_;
-  int x_, y_, width_, height_, dolegends_, dousedlegends_;
+  int x_, y_, width_, height_, docaptions_, dolegends_, dousedlegends_;
   int priority_, counter_;
   char *title_, *legend_;
   unsigned long textcolor_;
