@@ -4,13 +4,14 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: xosview.cc,v 1.13 1998/05/17 21:22:28 bgrayson Exp $
+// $Id: xosview.cc,v 1.26 1999/02/26 23:36:19 bgrayson Exp $
 //
 #include <iostream.h>
 #include <unistd.h>
 #include <string.h>
 #include <stdlib.h>
 #include <sys/time.h>
+#include "snprintf.h"
 #include "general.h"
 #include "xosview.h"
 #include "meter.h"
@@ -22,9 +23,9 @@
 static const char NAME[] = "xosview@";
 #include "version.cc"
 
-int MAX_SAMPLES_PER_SECOND = 10;
+double MAX_SAMPLES_PER_SECOND = 10;
 
-CVSID("$Id: xosview.cc,v 1.13 1998/05/17 21:22:28 bgrayson Exp $");
+CVSID("$Id: xosview.cc,v 1.26 1999/02/26 23:36:19 bgrayson Exp $");
 CVSID_DOT_H(XOSVIEW_H_CVSID);
 
 
@@ -37,11 +38,18 @@ XOSView::XOSView( char * instName, int argc, char *argv[] ) : XWin(),
   //  XWinInit looks at the geometry resource for its geometry.  BCG
   xrm.loadAndMergeResources (argc, argv, display_); 
   XWinInit (argc, argv, NULL, &xrm);
-#if 0	//  Don't enable this yet.
-  MAX_SAMPLES_PER_SECOND = atoi(getResource("samplesPerSec"));
+#if 1	//  Don't enable this yet.
+  MAX_SAMPLES_PER_SECOND = atof(getResource("samplesPerSec"));
   if (!MAX_SAMPLES_PER_SECOND)
     MAX_SAMPLES_PER_SECOND = 10;
 #endif
+  usleeptime_ = (unsigned long) (1000000/MAX_SAMPLES_PER_SECOND);
+  if (usleeptime_ >= 1000000) {
+    /*  The syscall usleep() only takes times less than 1 sec, so
+     *  split into a sleep time and a usleep time if needed.  */
+    sleeptime_ = usleeptime_ / 1000000;
+    usleeptime_ = usleeptime_ % 1000000;
+  } else { sleeptime_ = 0; }
 #if (defined(XOSVIEW_NETBSD) || defined(XOSVIEW_FREEBSD) || defined(XOSVIEW_OPENBSD))
   BSDInit();	/*  Needs to be done before processing of -N option.  */
 #endif
@@ -53,6 +61,10 @@ XOSView::XOSView( char * instName, int argc, char *argv[] ) : XWin(),
   meters_ = NULL;
   name_ = "xosview";
   _isvisible = false;
+  _ispartiallyvisible = false;
+  exposed_once_flag_ = 0;
+
+  expose_flag_ = 1;
 
   //  set up the X events
   addEvent( new Event( this, ConfigureNotify, 
@@ -102,7 +114,7 @@ void XOSView::figureSize ( void ) {
     else
       xoff_ = textWidth( "XXXXXXXXX" );
 
-    yoff_ = textHeight() + textHeight() / 4;
+    yoff_ = caption_ ? textHeight() + textHeight() / 4 : 0;
   }
   static int firsttime = 1;
   if (firsttime) {
@@ -131,6 +143,7 @@ int XOSView::newypos( void ){
 void XOSView::dolegends( void ){
   MeterNode *tmp = meters_;
   while ( tmp != NULL ){
+    tmp->meter_->docaptions( caption_ );
     tmp->meter_->dolegends( legend_ );
     tmp->meter_->dousedlegends( usedlabels_ );
     tmp = tmp->next_;
@@ -162,7 +175,7 @@ int XOSView::findx( void ){
 
 int XOSView::findy( void ){
   if ( legend_ )
-    return 10 + textHeight() * nummeters_ * 2;
+    return 10 + textHeight() * nummeters_ * ( caption_ ? 2 : 1 );
 
   return 15 * nummeters_;
 }
@@ -172,25 +185,29 @@ void XOSView::checkOverallResources() {
 
   //  Set 'off' value.  This is not necessarily a default value --
   //    the value in the defaultXResourceString is the default value.
-  usedlabels_ = legend_ = 0;
+  usedlabels_ = legend_ = caption_ = 0;
 
   setFont();
   
+   // use captions
+  if ( isResourceTrue("captions") )
+      caption_ = 1;
+  
   // use labels
-  if ( !strcmp( getResource("labels"), "True" ) )
+  if ( isResourceTrue("labels") )
       legend_ = 1;
-
+  
   // use "free" labels
-  if ( !strcmp( getResource("usedlabels"), "True" ) )
-    usedlabels_ = 1;
+  if ( isResourceTrue("usedlabels") )
+      usedlabels_ = 1;
 }
 
 const char *XOSView::winname( void ){
-  static char name[100];
   char host[100];
-  strcpy( name, NAME );
   gethostname( host, 99 );
-  strcat( name, host );
+  static char name[101];	/*  We return a pointer to this,
+				    so it can't be local.  */
+  snprintf( name, 100, "%s%s", NAME, host);
   //  Allow overriding of this name through the -title option.
   return getResourceOrUseDefault ("title", name);
 }
@@ -221,16 +238,31 @@ XOSView::~XOSView( void ){
   }
 }
 
-void XOSView::draw( void ){
+void XOSView::reallydraw( void ){
+  XOSDEBUG("Doing draw.\n");
   clear();
   MeterNode *tmp = meters_;
+
   while ( tmp != NULL ){
     tmp->meter_->draw();
     tmp = tmp->next_;
   }
   flush();
+
+  expose_flag_ = 0;
 }
 
+void XOSView::draw ( void ) {
+  if (hasBeenExposedAtLeastOnce() && isAtLeastPartiallyVisible())
+    reallydraw();
+  else {
+    if (!hasBeenExposedAtLeastOnce()) {
+      XOSDEBUG("Skipping draw:  not yet exposed.\n");
+    } else if (!isAtLeastPartiallyVisible()) {
+      XOSDEBUG("Skipping draw:  not visible.\n");
+    }
+  }
+}
 void XOSView::keyrelease( char *ch ){
 /*  WARNING:  This code is not called by anything.  */
 (void) ch;  /*  To avoid gcc warnings.  */
@@ -252,11 +284,13 @@ void XOSView::run( void ){
 
       flush();
     }
-    unsigned long usleeptime = 1000000/MAX_SAMPLES_PER_SECOND;
 #ifdef HAVE_USLEEP
-    usleep( usleeptime );
+    /*  First, sleep for the proper integral number of seconds --
+     *  usleep only deals with times less than 1 sec.  */
+    if (sleeptime_) sleep((unsigned int)sleeptime_);
+    if (usleeptime_) usleep( (unsigned int)usleeptime_);
 #else
-    usleep_via_select ( usleeptime );
+    usleep_via_select ( usleeptime_ );
 #endif
     counter = (counter + 1) % 5;    
   }
@@ -265,7 +299,7 @@ void XOSView::run( void ){
 void XOSView::usleep_via_select( unsigned long usec ){
   struct timeval time;
 
-  time.tv_sec = usec / 1000000;
+  time.tv_sec = (int)(usec / 1000000);
   time.tv_usec = usec - time.tv_sec * 1000000;
 
   select( 0, 0, 0, 0, &time );
@@ -274,9 +308,8 @@ void XOSView::usleep_via_select( unsigned long usec ){
 void XOSView::keyPressEvent( XKeyEvent &event ){
   char c = 0;
   KeySym key;
-  XComposeStatus cs;
 
-  XLookupString( &event, &c, 1, &key, &cs );
+  XLookupString( &event, &c, 1, &key, NULL );
 
   if ( (c == 'q') || (c == 'Q') )
     done_ = 1;
@@ -302,7 +335,7 @@ void XOSView::checkArgs (int argc, char** argv) const
 		exit(0);
       case 'n': //  Check for -name option that was already parsed
 		//  and acted upon by main().
-		if (!strcmp(*argv, "-name"))
+		if (!strncasecmp(*argv, "-name", 6))
 		{
 		  argv++;	//  Skip arg to -name.
 		  argc--;
@@ -320,7 +353,7 @@ void XOSView::checkArgs (int argc, char** argv) const
 		break;
 #endif
       case '-':  /*  Check for --version argument.  */
-              if (!strcmp(*argv, "--version")) {
+              if (!strncasecmp(*argv, "--version", 10)) {
 	        cerr << versionString << endl;
 		exit(0);
 	      }
@@ -337,23 +370,37 @@ void XOSView::checkArgs (int argc, char** argv) const
 void XOSView::exposeEvent( XExposeEvent &event ) { 
   _isvisible = true;
   if ( event.count == 0 ) 
+  {
+    expose_flag_++;
     draw();
+  }
+  XOSDEBUG("Got expose event.\n");
+  if (!exposed_once_flag_) { exposed_once_flag_ = 1; draw(); }
 }
 
+void XOSView::resizeEvent( XEvent & ) {
+  resize(); 
+  expose_flag_++;
+  draw();
+}
+
+
 void XOSView::visibilityEvent( XVisibilityEvent &event ){
-  //cerr <<"XOSView::visibilityEvent() : ";
+  _ispartiallyvisible = false;
+  if (event.state == VisibilityPartiallyObscured){
+    _ispartiallyvisible = true;
+  }
+
   if (event.state == VisibilityFullyObscured){
-    //cerr <<"hidden";
     _isvisible = false;
   }
   else {
-    //cerr <<"not hidden";
     _isvisible = true;
   }
-  //cerr <<endl;
+  XOSDEBUG("Got visibility event; %d and %d\n",
+      _ispartiallyvisible, _isvisible);
 }
 
 void XOSView::unmapEvent( XUnmapEvent & ){
-  //cerr <<"XOSView::unmapEvent()" <<endl;
   _isvisible = false;
 }
