@@ -4,19 +4,19 @@
 //  This file may be distributed under terms of the GPL
 //
 //
-// $Id: xosview.h,v 1.6 1998/03/27 19:18:17 bgrayson Exp $
+// $Id: xosview.h,v 1.11 1999/02/26 23:36:20 bgrayson Exp $
 //
 #ifndef _XOSVIEW_H_
 #define _XOSVIEW_H_
 
-#define XOSVIEW_H_CVSID	"$Id: xosview.h,v 1.6 1998/03/27 19:18:17 bgrayson Exp $"
+#define XOSVIEW_H_CVSID	"$Id: xosview.h,v 1.11 1999/02/26 23:36:20 bgrayson Exp $"
 
 #include "xwin.h"
 #include "Xrm.h"  //  For Xrm resource manager class.
 
 
 /*  Take at most n samples per second (default of 10)  */
-extern int MAX_SAMPLES_PER_SECOND;
+extern double MAX_SAMPLES_PER_SECOND;
 
 class Meter;
 
@@ -27,7 +27,8 @@ public:
 
   void figureSize ( void );
   void resize( void );
-  void draw( void );
+  void reallydraw( void );
+  void draw ( void );
   void run( void );
   void keyrelease( char *ch );
   const char *winname( void );
@@ -36,6 +37,11 @@ public:
   int xoff(void) const { return xoff_; }
   int newypos( void );
 
+  int hasBeenExposedAtLeastOnce() const {return exposed_once_flag_; }
+  int isExposed() const { return expose_flag_; }
+  int isFullyVisible() const { return _isvisible && !_ispartiallyvisible; }
+  int isAtLeastPartiallyVisible() const { return _isvisible; }
+
 protected:
 
   Xrm xrm;
@@ -50,7 +56,10 @@ protected:
 
   MeterNode *meters_;
   
-  int legend_, xoff_, yoff_, nummeters_, usedlabels_;
+  int caption_, legend_, xoff_, yoff_, nummeters_, usedlabels_;
+  unsigned long sleeptime_, usleeptime_;
+
+  int expose_flag_, exposed_once_flag_;
 
   void usleep_via_select( unsigned long usec );
   void addmeter( Meter *fm );
@@ -61,7 +70,7 @@ protected:
   void dolegends( void );
 
   void checkOverallResources();
-  void resizeEvent( XEvent &) { resize(); draw(); }
+  void resizeEvent( XEvent & );
   void exposeEvent( XExposeEvent &event );
   void keyPressEvent( XKeyEvent &event );
   void visibilityEvent( XVisibilityEvent &event );
@@ -69,6 +78,11 @@ protected:
 private:
 
   bool _isvisible;
+  bool _ispartiallyvisible;
 };
 
+/*  Make XOSDEBUG("This is a format string.  %d %d\n", a, b); look
+ *  like if (0) printf("This ..."...);.  Change the 0 to a 1, to
+ *  enable these debugging outputs.  */
+#define XOSDEBUG	if (0) printf
 #endif
