@@ -1,16 +1,16 @@
 //
-// $Id: xwin.cc,v 1.8 1997/04/15 23:40:26 bgrayson Exp $
+// $Id: xwin.cc,v 1.14 1999/01/25 21:22:10 mromberg Exp $
 //
 
 #include <X11/Xatom.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include "snprintf.h"
 #include "general.h"
 #include "xwin.h"
 #include "Xrm.h"
 
-CVSID("$Id: xwin.cc,v 1.8 1997/04/15 23:40:26 bgrayson Exp $");
+CVSID("$Id: xwin.cc,v 1.14 1999/01/25 21:22:10 mromberg Exp $");
 CVSID_DOT_H(XWIN_H_CVSID);
 
 //-----------------------------------------------------------------------------
@@ -22,8 +22,8 @@ XWin::XWin(){
 //-----------------------------------------------------------------------------
 
 XWin::XWin( int argc, char *argv[], int x, int y, int width, int height ){
-  fprintf (stderr, "This constructor call is not supported!  (%s:%d)\n",
-    __FILE__, __LINE__);
+  cerr << "This constructor call is not supported! (" << __FILE__
+       << ":" << __LINE__ << ")" << endl;
   exit (-1);
   //  FIXME BCG  This constructor needs to do much of the work of the above
   //  one.  Or, we need to drop this as a constructor.  As it is, it is
@@ -53,9 +53,9 @@ void XWin::XWinInit (int argc, char** argv, char* geometry, Xrm* xrm) {
   
   // Set up the default Events
   events_ = NULL;
-  addEvent( new Event( this, ConfigureNotify, &configureEvent ) );
-  addEvent( new Event( this, ClientMessage, &deleteEvent ) );
-  addEvent( new Event( this, MappingNotify, &mappingNotify ) );
+  addEvent( new Event( this, ConfigureNotify, &XWin::configureEvent ) );
+  addEvent( new Event( this, ClientMessage, &XWin::deleteEvent ) );
+  addEvent( new Event( this, MappingNotify, &XWin::mappingNotify ) );
 
   //openDisplay();  //  Done explicitly in xosview.cc.
 }
@@ -86,10 +86,15 @@ XWin::~XWin( void ){
 void XWin::init( int argc, char **argv ){
   XGCValues            gcv;
   XSetWindowAttributes xswa;
+  Pixmap	       background_pixmap;
+  int		       doPixmap = 0;
 
   setFont();
   setColors();
   getGeometry();
+#ifdef HAVE_XPM
+  doPixmap=getPixmap(&background_pixmap);
+#endif
   
   window_ = XCreateSimpleWindow(display_, DefaultRootWindow(display_), 
 				sizehints_->x, sizehints_->y,
@@ -112,6 +117,12 @@ void XWin::init( int argc, char **argv ){
   XChangeWindowAttributes(display_, window_,
 			  (CWColormap | CWBitGravity), &xswa);
 
+  // If there is a pixmap file, set it as the background
+  if(doPixmap)
+  {
+	XSetWindowBackgroundPixmap(display_,window_,background_pixmap);
+  }
+
   // add the events
   Event *tmp = events_;
   while ( tmp != NULL ){
@@ -222,6 +233,39 @@ void XWin::setColors( void ){
 }
 //-----------------------------------------------------------------------------
 
+int XWin::getPixmap(Pixmap *pixmap)
+{
+#ifdef HAVE_XPM
+	char	*pixmap_file;
+	XWindowAttributes    root_att;
+	XpmAttributes        pixmap_att;
+
+
+	pixmap_file = (char*) getResourceOrUseDefault("pixmapName",NULL);
+
+	if(pixmap_file)
+	{
+		XGetWindowAttributes(display_, DefaultRootWindow(display_),&root_att);
+		pixmap_att.closeness=30000;
+		pixmap_att.colormap=root_att.colormap;
+		pixmap_att.valuemask=XpmSize|XpmReturnPixels|XpmColormap|XpmCloseness;
+		if(XpmReadFileToPixmap(display_,DefaultRootWindow(display_),pixmap_file, pixmap, NULL, &pixmap_att))
+        	{
+                	cerr << "Pixmap " << pixmap_file  << " not found" << endl;
+                	cerr << "Defaulting to blank" << endl;
+                	pixmap=NULL;
+			return 0; // OOps
+        	}
+		return 1;  // Good, found the pixmap
+  	}
+	return 0; // No file specified, none used
+#else
+	(void) pixmap;
+	cerr << "Error:  getPixmap called, when Xpm is not enabled!\n" ;
+	return 0;
+#endif
+}
+
 void XWin::getGeometry( void ){
   char                 default_geometry[80];
   int                  bitmask;
@@ -241,7 +285,7 @@ void XWin::getGeometry( void ){
   sizehints_->y = y_;
 
   // Construct a default geometry string
-  sprintf(default_geometry, "%dx%d+%d+%d", sizehints_->width,
+  snprintf(default_geometry, 80, "%dx%d+%d+%d", sizehints_->width,
 	  sizehints_->height, sizehints_->x, sizehints_->y);
 
   // Process the geometry specification
@@ -306,7 +350,6 @@ void XWin::checkevent( void ){
 #if 0
 void XWin::usage( void ){
   //  FIXME  We need to update this.  BCG
-#warning The usage() function needs to be updated.
   cerr <<name_ <<" [-display name] [-geometry geom]" <<endl;
 //    exit (1);
 }
